@@ -45,6 +45,6 @@ end
 # Workaround for https://github.com/cucumber/aruba/pull/125
 Aruba.configure do |config|
   config.before_cmd do
-    set_env("JRUBY_OPTS", "-X-C --1.9")
+    set_env("JRUBY_OPTS", "--dev --debug")
   end
 end
